from typing import List
from ....Types import Good
from ....Types import Good, Category
from ....Utils import Response


class BaseGame:

    def __init__(self, wrapper) -> None:
        self.__wrapper = wrapper
        self.name = None

    async def search(
        self,
        page: int = 1,
        pmin: int | None = None,
        pmax: int | None = None,
        title: str | None = None,
        parse_sticky_items: bool | None = None,
        parse_same_items: bool | None = None,
        game: list[int] | None = None,
        **kwargs
    ) -> list[Good.Account]:
        """Private method for execute search"""
        params = {}

        arg_types = {
            "page": int,
            "pmin": int,
            "pmax": int,
            "title": str,
            "parse_sticky_items": bool,
            "parse_same_items": bool,
            "game": list,
        }

        for arg_name, arg_type in arg_types.items():
            arg_value = locals()[arg_name]
            if arg_value is not None and not isinstance(arg_value, arg_type):
                raise TypeError(
                    f"{arg_name} must be {arg_type.__name__} or None!")

        if page < 1:
            raise ValueError("page must be equal to or bigger than 1")
        params['page'] = page

        if pmin is not None:
            params['pmin'] = pmin
        if pmax is not None:
            params['pmax'] = pmax
        if title is not None:
            params['title'] = title
        if parse_sticky_items is not None:
            params['parse_sticky_items'] = parse_sticky_items
        if parse_same_items is not None:
            params['parse_same_items'] = parse_same_items
        if game is not None:
            params['game'] = game

        for arg in kwargs.keys():
            params[arg] = kwargs[arg]
        response = await self.__wrapper._execute(
            f"/{self.name}",
            "get",
            params=params
        )

        return Response.response_to_accounts(self.__wrapper, response['items'])



from typing import List

from ..Types.Category import *
from ..Types.Good import *
from ..Types.AccountManage import AccountManager


def response_to_accounts(wrapper, account_list: List) -> List[AccountManager]:
    result = []
    for acc in account_list:
        if not acc['category_id'] in CATEG_AND_ACCOUNT.keys():
            acc_module = Account.parse_obj(acc)
            acc_module.unfiltered_account_data = acc
            result.append(
                AccountManager(
                    wrapper,
                    acc['item_id'],
                    acc_module,
                ))
            continue
        result.append(
            AccountManager(
                wrapper,
                acc['item_id'],
                CATEG_AND_ACCOUNT[acc['category_id']].parse_obj(acc),
            )
        )
    return result


__all__ = ['response_to_accounts']



from typing import List

from lztmarket.Types import Good
from ....Types import Good, Category
from .BaseGame import BaseGame
from ....Types.AccountManage import AccountManager


class Fortnite(BaseGame):

    def __init__(self, wrapper) -> None:
        super().__init__(wrapper)
        self.categ_obj = Category.FORTNITE
        
        self.name = self.categ_obj.name
        self.categ_id = self.categ_obj.id

    async def search(self, page: int = 1, pmin: int | None = None, pmax: int | None = None, title: str | None = None, parse_sticky_items: bool | None = None, parse_same_items: bool | None = None, game: list[int] | None = None, **kwargs) -> List[AccountManager]:
        """smin (number) - Minimum number of skins

smax (number) - Maximum number of skins

vbmin (number) - Minimum number of V-Bucks

vbmax (number) - Maximum number of V-Bucks

skin (array) - Skins

pickaxe (array) - Pickaxes

dance (array) - Dances

glider (array) - Gliders

change_email (boolean) - Can change email

platform (array) - Platform

bp (boolean) - Has Battle Pass

lmin (number) - Minimum level

lmax (number) - Maximum level

bp_lmin (number) - Minimum level of Battle Pass

bp_lmax (number) - Maximum level of Battle Pass

rl_purchases (boolean) - Has Rocket League purchases

last_trans_date (number) - How old is last transaction

last_trans_date_period (string) - In what notation is time measured

no_trans (boolean) - Has no transactions

xbox_linkable (boolean) - Can be linked to Xbox

psn_linkable (boolean) - Can be linked to PSN

daybreak (number) - Number of days the account has been offline

temp_email (boolean) - Access to market temp mail"""
        return await super().search(page, pmin, pmax, title, parse_sticky_items, parse_same_items, game, **kwargs)


from typing import Dict, List, Optional, Any
from enum import Enum
from pydantic import BaseModel

from .Category import *

from .User import Seller


class Account(BaseModel):
    item_id: int
    category_id: int
    published_date: int
    title: str
    title_en: str
    item_origin: str
    price: int
    allow_ask_discount: int
    price_currency: str
    temp_email: str = None
    description: str
    view_count: int
    is_reserved: int
    item_domain: str = None
    seller: Seller
    cannotBuyItemError: str = None
    canStickItem: bool = False
    canUnstickItem: bool = False
    canBuyItem: bool = False
    canCloseItem: bool = False
    canOpenItem: bool = False
    canReportItem: bool = False
    canEditItem: bool = False
    canDeleteItem: bool = False
    canCancelConfirmedBuy: bool = False
    canViewItemHistory: bool = False
    faveCount: bool = False
    isVisibleItem: bool = False
    canViewLoginData: bool = False
    unfiltered_account_data: dict = None


class VkAccount(Account):
    vk_item_id: int
    vk_id: int = None
    vk_id_count: int = None
    vk_friend_count: int = None
    vk_follower_count: int = None
    vk_admin_groups: list = None
    vk_max_group_follower_count: int = None
    vk_vote_count: int = None
    vk_country: str = None
    vk_sex: str = None
    vk_mobile: str = None
    vk_register_date: int = None
    vk_age: int = None
    vk_city: str = None
    vk_email: int = None
    vk_mobile_country: int = None
    vk_tfa: int = None
    vk_is_closed: int = None
    vk_relation: int = None
    vk_count_conversations: int = None
    vk_mobile_country: str = None
    vk_sex_phrase: str = None
    vk_relation_phrase: str = None
    vk_token: str = None
    vk_ua: str = None


class SteamAccount(Account):
    steam_item_id: int = None
    account_country: str = None
    steam_register_date: int = None
    steam_last_activity: int = None
    account_full_games: dict = None
    account_community_ban: int = None
    steam_csgo_profile_rank: int = None
    account_balance: str = None
    account_csgo_rank_id: int = None
    last_update_time: int = None
    steam_is_limited: int = None
    steam_level: int = None
    steam_friend_count: int = None
    steam_csgo_last_activity: int = None
    steam_dota2_solo_mmr: int = None
    steam_dota2_party_mmr: int = None
    steam_csgo_ban_date: int = None
    steam_converted_balance: int = None
    steam_pubg_inv_value: int = None
    steam_csgo_inv_value: int = None
    steam_dota2_inv_value: int = None
    steam_tf2_inv_value: int = None
    steam_rust_inv_value: int = None
    steam_csgo_wingman_rank_id: int = None
    steam_game_count: int = None
    steam_steam_inv_value: int = None
    steam_inv_value: int = None
    steam_csgo_win_count: int = None
    steam_dota2_game_count: int = None
    steam_dota2_lose_count: int = None
    steam_dota2_win_count: int = None
    steam_hours_played_recently: float = None
    steam_faceit_level: int = None
    steam_points: int = None
    steam_last_transaction_date: int = None
    steam_relevant_game_count: int = None
    steam_gift_count: int = None
    steam_limit_spent: str = None
    steam_dota2_behavior: int = None
    steam_has_faceit: int = None
    steam_mfa: int = None
    steam_market: int = None
    steam_market_restrictions: str = None
    steam_market_ban_end_date: int = None
    steam_unturned_inv_value: int = None
    steam_csgo_last_launched: int = None
    steam_kf2_inv_value: int = None
    steam_dst_inv_value: int = None
    steamData: dict = None
    steamRelevantGameCount: int = None
    hasCsgo: bool = None
    isSmallExf: bool = None
    hasDota2: bool = None
    hasPubg: bool = None
    hasTf2: bool = None
    hasRust: bool = None
    inventoryValue: dict = None
    steamCsgoMedals: list = None
    steamTransactions: list = None
    canSteamPreviewProfile: bool = None
    canSteamPreviewGames: bool = None
    hasPossibleBanInDota2: bool = None
    chineseAccount: bool = None
    canViewAccountLink: bool = None


class OriginGame(BaseModel):
    game_id: str
    title: str
    last_activity: int
    total_played: int
    is_full: bool
    img: str


class OriginAccount(Account):
    ea_item_id: int
    ea_id: int
    ea_account_country: str
    ea_account_games: str
    ea_last_activity: int
    ea_al_level: int
    ea_al_rank: str
    ea_subscription: str
    ea_subscription_end_date: int
    ea_username: str
    ea_al_rank_group: str
    ea_skip_email_check: int
    ea_xbox_connected: int
    ea_steam_connected: int
    ea_account_full_games: Optional[Dict[str, OriginGame]] = None


class WarfaceItemInfo(BaseModel):
    id: int
    title: str
    itemid: str
    count: str
    duration: str
    duration_type: str
    consumable: str
    permanent: str
    regular: str
    priority: str
    tag: str
    type: str
    limit: str


class WarfaceGun(BaseModel):
    cartid: str
    csaid: str
    itemid: str
    itemcount: str
    last_update: str
    promoid: str
    tid: str
    iteminfo: WarfaceItemInfo


class WarfaceServer(BaseModel):
    id: int
    rank: int
    title: str


class WarfaceAccount(Account):
    wf_item_id: int
    wf_players: List[Any]
    wf_guns: Dict[str, List[WarfaceGun]]
    wf_server_1: int
    wf_server_2: int
    wf_server_3: int
    wf_mobile: int
    wf_bonus_rank: int
    wf_last_game_date: int
    wf_loan: Optional[Any]
    wf_active_loan: int
    wf_rank: int
    wf_gun_count: int = None
    wf_servers: List[WarfaceServer]
    domain: str

class UplayAccount(Account):
    uplay_item_id: int
    uplay_account_last_activity: int
    uplay_account_country: str
    uplay_account_created_date: int
    uplay_account_full_games: dict
    uplay_account_r6_level: int

class SocialClubAccount(Account):
    socialclub_item_id: int
    socialclub_id: str
    socialclub_level: int
    socialclub_cash: int
    socialclub_bank_cash: int
    socialclub_games: list
    socialclub_last_activity: int
    socialclub_has_gtav: int
    socialclub_has_rdr2: int




CATEG_AND_ACCOUNT = {
    STEAM.id: SteamAccount,
    VK.id: VkAccount,
    ORIGIN.id: OriginAccount,
    WARFACE.id: WarfaceAccount,
    UPLAY.id: UplayAccount,
    SOCIAL_CLUB.id: SocialClubAccount
}



from .Steam import Steam
from .VK import VK
from .Origin import Origin
from .Warface import Warface
from .Uplay import Uplay
from .SocialClub import SocialClub
from .Fortnite import Fortnite
from .Instagram import Instagram
from .Battlenet import Battlenet
from .EpicGames import EpicGames
from .Valorant import Valorant
from .WorldOfTanks import WorldOfTanks
from .Blitz import Blitz
from .Supercell import Supercell
from .GenshinImpact import GenshinImpact
from .EscapeFromTarkov import EscapeFromTarkov
from .VPN import VPN
from .TikTok import TikTok
from .Discord import Discord
from .Cinema import Cinema
from .Telegram import Telegram
from .YouTube import YouTube
from .Spotify import Spotify
from .WarThunder import WarThunder




from pydantic import BaseModel
from typing import Optional


class SystemInfo(BaseModel):
    visitor_id: Optional[int]
    time: Optional[int]

class User(BaseModel):
    user_id: Optional[int]
    username: Optional[str]
    user_message_count: Optional[int]
    user_register_date: Optional[int]
    user_like_count: Optional[int]
    short_link: Optional[str]
    user_email: Optional[str]
    user_unread_notification_count: Optional[int]
    user_dob_day: Optional[int]
    user_dob_month: Optional[int]
    user_dob_year: Optional[int]
    user_title: Optional[str]
    user_last_seen_date: Optional[int]
    balance: Optional[int]
    hold: Optional[int]
    system_info: Optional[SystemInfo]


from typing import List

from lztmarket.Types import Good
from ....Types import Good, Category
from .BaseGame import BaseGame
from ....Types.AccountManage import AccountManager


class Spotify(BaseGame):

    def __init__(self, wrapper) -> None:
        super().__init__(wrapper)
        self.categ_obj = Category.SPOTIFY
        self.name = self.categ_obj.name
        self.categ_id = self.categ_obj.id

    async def search(self, page: int = 1, pmin: int | None = None, pmax: int | None = None, title: str | None = None, parse_sticky_items: bool | None = None, parse_same_items: bool | None = None, game: list[int] | None = None, **kwargs) -> List[AccountManager]:
        """country[] (array) - List of allowed countries

not_country[] (array) - List of disallowed countries

family (boolean) - Has family subscription

family_manager (boolean) - Has family manager permissions

family_member_count_min (number) - Minimum count of members in family

family_member_count_max (number) - Maximum count of members in family

subscription_length (number) - Length of subscription

subscription_period (string) - In what notation is time measured

recurring (boolean) - Is auto renewal enabled

trial (boolean) - Trial subscription

plan_name[] (array) - List of allowed plans"""
        return await super().search(page, pmin, pmax, title, parse_sticky_items, parse_same_items, game, **kwargs)


from typing import List

from lztmarket.Types import Good
from ....Types import Good, Category
from .BaseGame import BaseGame
from ....Types.AccountManage import AccountManager


class Valorant(BaseGame):

    def __init__(self, wrapper) -> None:
        super().__init__(wrapper)
        self.categ_obj = Category.VALORANT
        self.name = self.categ_obj.name
        self.categ_id = self.categ_obj.id

    async def search(self, page: int = 1, pmin: int | None = None, pmax: int | None = None, title: str | None = None, parse_sticky_items: bool | None = None, parse_same_items: bool | None = None, game: list[int] | None = None, **kwargs) -> List[AccountManager]:
        """weaponSkin[] (array) - List of weapon skis

buddy[] (array) - List of buddies

agent[] (array) - List of agents

country[] (array) - List of allowed countries

not_country[] (array) - List of disallowed countries

daybreak (number) - Number of days the account has been offline

level_min (number) - Minimum level

level_max (number) - Maximum level

vp_min (number) - Minimum number of Valorant points

vp_max (number) - Maximum number of Valorant points

smin (number) - Minimum number of skins

smax (number) - Maximum number of skins

rmin (number) - Minimum rank (from 3 to 27)

rmax (number) - Maximum rank

last_rmin (number) - Last Minimum rank (from 3 to 27)

last_rmax (number) - Last Maximum rank

rank_type (string) - Rank type

amin (number) - Minimum amount of agents

amax (number) - Maximum amount of agents

region[] (array) - List of allowed regions

not_region[] (array) - List of disallowed regions

email (boolean) - Has linked email

tel (boolean) - Has linked mobile

changeable_email (boolean) - Can change email"""
        return await super().search(page, pmin, pmax, title, parse_sticky_items, parse_same_items, game, **kwargs)


from ...ApiWrapper import Wrapper
from ...Types import Good, Currency
from .ManageExceptions import NotEnoughRights, NotTempMail, NoAccountInfo


class AccountManager:

    def __init__(self, wrapper: Wrapper, account_id: int, account_info: Good.Account = None) -> None:
        self.__wraper = wrapper
        self.__account_id = account_id
        self.__account_info = account_info

    @property
    def id(self):
        return self.__account_id


    def __parse_info(self, data) -> Good.Account:
        if not data['item']['category_id'] in Good.CATEG_AND_ACCOUNT.keys():
            res = Good.Account.parse_obj(data['item'])
        else:
            res = Good.CATEG_AND_ACCOUNT[data['item']['category_id']].parse_obj(data['item'])
        res.unfiltered_account_data = data['item']
        return res
    
    async def __get_info(self) -> Good.Account:
        account_info_not_sorted = await self.__wraper._execute(
            f"/{self.__account_id}",
            "get"
        )
        return self.__parse_info(account_info_not_sorted)

    async def get_info(self, recheck: bool = False) -> Good.Account:
        """
        Возвращает информацию об аккаунте.

        :param recheck: флаг, указывающий нужно ли выполнить повторный запрос для получения информации об аккаунте.
        :type recheck: bool, optional
        :return: информация об аккаунте.
        :rtype: Good.Account
        """
        if not (self.__account_info and not recheck):
            data = await self.__get_info()
            self.__account_info.unfiltered_account_data = data

        if not self.__account_id:
            self.__account_id = self.__account_info.item_id
        return self.__account_info

    # async def check(self) -> Good.Account:
    #     "OUTDATED"
    #     return

    #     data = await self.__wraper._execute(
    #         f"/{self.__account_id}/check-account",
    #         "post"
    #     )
    #     return Good.CATEG_AND_ACCOUNT[data['item']['category_id']].parse_obj(data['item'])

    async def delete(self, reason: str = "") -> None:
        """
        Удаляет аккаунт.

        :param reason: причина удаления аккаунта.
        :type reason: str, optional
        :raises NotEnoughRights: если у аккаунта нет прав на удаление.
        """
        if not self.__account_info.canDeleteItem:
            raise NotEnoughRights(
                f"Not enough rights to delete {self.__account_id}")
        self.__wraper._execute(
            f"/{self.__account_id}",
            "delete",
            params={"reason": reason}
        )

    async def get_mail_code(self, mail: str = None) -> str:
        """
        Получает код подтверждения для указанного временного адреса электронной почты.

        :param mail: временный адрес электронной почты. Если не указан, будет использован адрес, связанный с аккаунтом.
        :type mail: str, optional
        :return: код подтверждения.
        :rtype: str
        :raises NotTempMail: если аккаунт не имеет временного адреса электронной почты, а параметр `mail` не был передан.
        :raises NoAccountInfo: если нет информации об аккаунте.
        """
        params = {}
        if self.__account_info and not self.__account_info.temp_email and not mail:
            raise NotTempMail("The account does not have a temporary email.")
        elif not self.__account_info:
            raise NoAccountInfo("No information about account.")

        params['email'] = mail

        if self.__account_info.temp_email:
            params['email'] = self.__account_info.temp_email

        response = await self.__wraper._execute(
            f"/{self.__account_id}/email-code",
            'get',
            params=params
        )
        return response['codeData']['code']

    async def get_guard_code(self) -> str:
        """
        Получает код Guard для аккаунта.

        :return: код Guard.
        :rtype: str
        :raises NoAccountInfo: если нет информации об аккаунте.
        """
        if not self.__account_id:
            raise NoAccountInfo("No information about account.")

        response = await self.__wraper._execute(
            f"/{self.__account_id}/guard-code",
            'get',
        )
        return response['codeData']['code']

    async def get_mafile(self) -> dict:
        """
        Возвращает MA-файл для аккаунта.

        :return: MA-файл.
        :rtype: dict
        :raises NoAccountInfo: если нет информации об аккаунте.
        """
        if not self.__account_id:
            raise NoAccountInfo("No information about account.")

        return await self.__wraper._execute(
            f"/{self.__account_id}/mafile",
            'get',
        )

    async def refuse_guarantee(self) -> None:
        """
        Отменяет гарантию на аккаунт.
        """
        return await self.__wraper._execute(
            f"/{self.__account_id}/refuse-guarantee",
            'post',
        )

    async def decline_safe_about_password(self) -> None:
        """Отмена предложения сменить пароль.
        """
        return await self.__wraper._execute(
            f"/{self.__account_id}/change-password",
            'post',
            params={'_cancel': 1}
        )

    async def change_password(self) -> None:
        """Подтверждение рекомендаций безопасности.
        """
        return await self.__wraper._execute(
            f"/{self.__account_id}/change-password",
            'post'
        )

    async def get_tempmail_password(self) -> None:
        """Получить пароль от временной почты.
        """
        return (await self.__wraper._execute(
            f"/{self.__account_id}/temp-email-password",
            'get'
        ))['item']['tempEmailData']['password']
    "Purchasing"

    async def edit(
            self,
            currency: str=Currency.RUB,
            title: str=None,
            title_en: str=None,
            price: int=None,
            item_origin: str=None,
            description: str=None,
            information: str=None,
            has_email_login_data: bool=None,
            email_login_data: str=None,
            email_type: str=None,
            allow_ask_discount: bool=None,
            proxy_id: int=None
            ) -> None:
        """
        Обновление информации об аккаунте

        Параметры:
        - валюта (необязательно): Валюта, в которой указывается цена счета. Допустимые значения: "cny", "usd", "rub", "eur", "uah", "kzt", "byn" и "gbp". Значение по умолчанию - "rub".
        - title (необязательно): Название счета на русском языке.
        - title_en (необязательно): Название счета на английском языке.
        - price (необязательно): Цена счета в вашей валюте.
        - item_origin (необязательно): Происхождение счета.
        - description (необязательно): Публичное описание счета.
        - информация (необязательно): Закрытая информация об аккаунте, видимая покупателю только в случае покупки.
        - has_email_login_data (необязательно): Булево значение, указывающее, имеются ли данные для входа в систему по электронной почте.
        - email_login_data (необязательно): Данные для входа в систему по электронной почте в формате "логин:пароль".
        - email_type (необязательный): Тип электронной почты. Допустимые значения: "native" и "autoreg".
        - allow_ask_discount (необязательно): Булево значение, указывающее, могут ли пользователи просить скидку для этого аккаунта.
        - proxy_id (необязательно): Идентификатор прокси, который будет использоваться для проверки аккаунта. Список прокси можно получить или отредактировать с помощью конечной точки GET /account/market.

        Возвращает:
        - None
        """ 
        non_none_params = {k: v for k, v in locals().items() if v is not None and k != 'self'}
        params={}

        params['currency'] = non_none_params['currency']

        del non_none_params['currency']

        for param in non_none_params.keys():
            params[f'key_values[{param}]'] = non_none_params[param]

        return await self.__wraper._execute(
            f'/{self.__account_id}/edit',
            'put',
            params=params
        )
    
    async def bump(self) -> None:
        """Поднятие аккаунта
        """
        return await self.__wraper._execute(
            f'/{self.__account_id}/bump',
            'post'
        )

    async def favorite(self) -> None:
        """Добавить аккаунт в избранное
        """
        return await self.__wraper._execute(
            f'/{self.__account_id}/star',
            'post'
        )
    
    async def unfavorite(self) -> None:
        """Убрать аккаунт из избранного.
        """
        return await self.__wraper._execute(
            f'/{self.__account_id}/star',
            'delete'
        )

    async def stick(self) -> None:
        """Закрепить аккаунт
        """
        return await self.__wraper._execute(
            f'/{self.__account_id}/stick',
            'post'
        )
    
    async def unstick(self) -> None:
        """Закрепить аккаунт
        """
        return await self.__wraper._execute(
            f'/{self.__account_id}/stick',
            'delete'
        )
    
    async def change_owner(self, new_owner_username: str, secret: str):
        params = dict(username=new_owner_username, secret_answer=secret)
        return await self.__wraper._execute(
            f'/{self.__account_id}/change-owner',
            'post',
            params
        )


    # async def reserve(self, price=None) -> None:
    #     """
    #     (OutDated | NotWork) Резервирует аккаунт.

    #     :param price: цена резерва.
    #     :type price: int, optional
    #     """
    #     return
    #     if price is None:
    #         price = self.__account_info.price

    #     await self.__wraper._execute(
    #         f"/{self.__account_id}/reserve",
    #         "post",
    #         params={"price": price}
    #     )

    async def buy(self, price: int = None, no_checK: bool = False) -> Good.Account:
        """
        Покупает аккаунт.

        :param price: цена покупки.
        :type price: int, optional
        :param no_checK: флаг, указывающий на необходимость отключения проверки при покупке.
        :type no_checK: bool, optional
        :return: купленный аккаунт.
        :rtype: Good.Account
        """
        no_checK = 1 if no_checK else 0
        if price is None:
            price = self.__account_info.price
        data = await self.__wraper._execute(
            f"/{self.__account_id}/fast-buy",
            "post",
            params={"price": price}
        )
        return Good.CATEG_AND_ACCOUNT[data['item']['category_id']].parse_obj(data['item'])

    async def add_to_unpublished(self, resell_item_id : int=None) -> str:
        """Get info about not published item. For categories, which required temporary email (Steam, Social Club), you will get temporary email in response.

        Parameters:

        resell_item_id (optional) Put item id, if you are trying to resell item. 
        This is useful to pass temporary email from reselling item to new item. 
        You will get same temporary email from reselling account."""

        params={}
        if resell_item_id is not None:
            params.update(resell_item_id=resell_item_id)
        
        data = self.__wraper._execute(
            f"{self.id}/goods/add",
            "get",
            params=params
        )
        self.__account_info = self.__parse_info(data)
        self.__account_info.temp_email = data['temp_mail']

        return data['temp_mail']

    async def check_for_publish(
            self,
            login: str=None,
            password: str=None,
            login_password: str=None,
            close_item: bool=None,
            extra: dict=None,
            resell_item_id: int=None,
            random_proxy: int=None
    ) -> bool:
        """Check account on validity. If account is valid, account will be published on the market.

        Parameters:

        login (optional) Account login (or email)
        password (optional) Account password
        login_password (optional) Account login data format login:password
        close_item (optional) If set, the item will be closed item_state = closed
        extra (optional) (Array) Extra params for account checking. E.g. you need to put cookies to extra[cookies] if you want to upload Fortnite/Epic Games account
        resell_item_id Put if you are trying to resell an account.
        random_proxy (optional) Pass 1, if you get "steam_captcha" in previous response"""
        non_none_params = {k: v for k, v in locals().items() if v is not None and k != 'self'}
        if 'extra' in non_none_params.keys():
            del non_none_params['extra']
        
        params={}

        params.update(**non_none_params)

        if extra is not None:
            for e in extra.keys():
                params[f"extra[{e}]"] = extra[e]

        unsorted_data = await self.__wraper._execute(
            f"/{self.__account_id}/goods/check",
            "post",
            params=params
        )
        return  True if unsorted_data['status'] == "ok" else False


from pydantic import BaseModel
from typing import Dict


class Label(BaseModel):
    title: str


class User(BaseModel):
    user_id: int
    user_balance: int
    user_hold: int
    user_balance_with_hold: int


class Payment(BaseModel):
    operation_id: int = None
    operation_date: int = None
    operation_type: str = None
    outgoing_sum: int = None
    incoming_sum: int = None
    item_id: int = None
    wallet: str = None
    is_finished: int = None
    is_hold: int = None
    payment_system: str = None
    data: dict | bool = None
    hold_end_date: int = None
    api: int = None
    cancelled: int = None
    payment_status: str = None
    canCancelBalanceTransfer: bool = None
    canCancelBalancePayout: bool = None
    canFinishBalanceTransfer: bool = None
    canFinishBalancePayout: bool = None
    label: Label = None
    user: User = None



from typing import List

from lztmarket.Types import Good
from ....Types import Good, Category
from .BaseGame import BaseGame
from ....Types.AccountManage import AccountManager


class Blitz(BaseGame):

    def __init__(self, wrapper) -> None:
        super().__init__(wrapper)
        self.categ_obj = Category.WORLD_OF_TANKS_BLITZ
        self.name = self.categ_obj.name
        self.categ_id = self.categ_obj.id

    async def search(self, page: int = 1, pmin: int | None = None, pmax: int | None = None, title: str | None = None, parse_sticky_items: bool | None = None, parse_same_items: bool | None = None, game: list[int] | None = None, **kwargs) -> List[AccountManager]:
        """tel (boolean) - Has linked mobile

daybreak (number) - Number of days the account has been offline

battles_min (number) - Minimum number of battles

battles_max (number) - Maximum number of battles

gold_min (number) - Minimum number of gold

gold_max (number) - Maximum number of gold

silver_min (number) - Minimum number of silver

silver_max (number) - Maximum number of silver

top_min (number) - Minimum number of top tanks

top_max (number) - Maximum number of top tanks

prem_min (number) - Minimum number of premium tanks

prem_max (number) - Maximum number of premium tanks

top_prem_min (number) - Minimum number of top premium tanks

top_prem_max (number) - Maximum number of top premium tanks

win_pmin (number) - Minimum number of wins

win_pmax (number) - Maximum number of wins

tank (array) - List of tanks

region (array) - Region

not_region (array) - Exclude region"""
        return await super().search(page, pmin, pmax, title, parse_sticky_items, parse_same_items, game, **kwargs)


from typing import NamedTuple
from enum import Enum


class Platform(NamedTuple):
    id: int
    name: str


STEAM = Platform(id=1, name="steam")
VK = Platform(id=2, name="vkontakte")
ORIGIN = Platform(id=3, name="origin")
WARFACE = Platform(id=4, name="warface")
UPLAY = Platform(id=5, name="uplay")
SOCIAL_CLUB = Platform(id=7, name="socialclub")
FORTNITE = Platform(id=9, name="fortnite")
INSTAGRAM = Platform(id=10, name="instagram")
BATTLENET = Platform(id=11, name="battlenet")
EPIC_GAMES = Platform(id=12, name="epicgames")
VALORANT = Platform(id=13, name="valorant")
WORLD_OF_TANKS = Platform(id=14, name="world-of-tanks")
SUPERCELL = Platform(id=15, name="supercell")
WORLD_OF_TANKS_BLITZ = Platform(id=16, name="wot-blitz")
GENSHIN_IMPACT = Platform(id=17, name="genshin-impact")
ESCAPE_FROM_TARKOV = Platform(id=18, name="escape-from-tarkov")
VPN = Platform(id=19, name="vpn")
TIKTOK = Platform(id=20, name="tiktok")
DISCORD = Platform(id=22, name="discord")
ONLINE_CINEMA = Platform(id=23, name="cinema")
TELEGRAM = Platform(id=24, name="telegram")
YOUTUBE = Platform(id=25, name="youtube")
SPOTIFY = Platform(id=26, name="spotify")
WAR_THUNDER = Platform(id=27, name="war-thunder")



from .Client import MarketClient
from .Types import Category

__all__ = (
    "__version__",
    "MarketClient",
    "ApiWrapper",
    "Client",
    "Types",
    "Utils"
)


__version__ = "0.0.1"
# もう「聞き飽きたんだよ、そのセリフ。」
# 中途半端だけは嫌



from typing import List

from lztmarket.Types import Good
from ....Types import Good, Category
from .BaseGame import BaseGame
from ....Types.AccountManage import AccountManager


class Cinema(BaseGame):

    def __init__(self, wrapper) -> None:
        super().__init__(wrapper)
        self.categ_obj = Category.ONLINE_CINEMA
        self.name = self.categ_obj.name
        self.categ_id = self.categ_obj.id

    async def search(self, page: int = 1, pmin: int | None = None, pmax: int | None = None, title: str | None = None, parse_sticky_items: bool | None = None, parse_same_items: bool | None = None, game: list[int] | None = None, **kwargs) -> List[AccountManager]:
        return await super().search(page, pmin, pmax, title, parse_sticky_items, parse_same_items, game, **kwargs)


from pydantic import BaseModel


class Seller(BaseModel):
    user_id: int = None
    sold_items_count: int = None
    restore_data: str = None
    username: str = None
    avatar_date: int = None
    is_banned: int = None
    display_style_group_id: int = None
    uniq_username_css: str = None
    restore_percents: int | None = None



from typing import Any
from ...ApiWrapper import Wrapper
from ...Types.Profile import User
class Me:

    def __init__(self, wrapper: Wrapper) -> None:
        self.__wrapper = wrapper

    async def info(self) -> User:
        data = await self.__wrapper._execute(
            "/me",
            "get"
        )
        return User.parse_obj(data['user'])


from typing import List

from lztmarket.Types import Good
from ....Types import Good, Category
from .BaseGame import BaseGame
from ....Types.AccountManage import AccountManager


class WarThunder(BaseGame):

    def __init__(self, wrapper) -> None:
        super().__init__(wrapper)
        self.categ_obj = Category.WAR_THUNDER
        self.name = self.categ_obj.name
        self.categ_id = self.categ_obj.id

    async def search(self, page: int = 1, pmin: int | None = None, pmax: int | None = None, title: str | None = None, parse_sticky_items: bool | None = None, parse_same_items: bool | None = None, game: list[int] | None = None, **kwargs) -> List[AccountManager]:
        """daybreak (number) - Number of days the account has been offline

gold_min (number) - Minimum number of gold

gold_max (number) - Maximum number of gold

silver_min (number) - Minimum number of silver

silver_max (number) - Maximum number of silver

rank_min (number) - Minimal rank

rank_max (number) - Maximum rank

eliteUnits_min (number) - Minimum number of elite units

eliteUnits_max (number) - Maximum number of elite units

played_min (number) - Minimum number of played games

played_max (number) - Maximum number of played games

wins_min (number) - Minimum number of wins

wins_max (number) - Maximum number of wins

phone_verified (boolean) - Has verified mobile

email_verified (boolean) - Has verified email

premium (boolean) - Has premium"""
        return await super().search(page, pmin, pmax, title, parse_sticky_items, parse_same_items, game, **kwargs)


from typing import List

from lztmarket.Types import Good
from ....Types import Good, Category
from .BaseGame import BaseGame
from ....Types.AccountManage import AccountManager


class VK(BaseGame):

    def __init__(self, wrapper) -> None:
        super().__init__(wrapper)
        self.categ_obj = Category.VK
        self.name = self.categ_obj.name
        self.categ_id = self.categ_obj.id

    async def search(self, page: int = 1, pmin: int | None = None, pmax: int | None = None, title: str | None = None, parse_sticky_items: bool | None = None, parse_same_items: bool | None = None, game: list[int] | None = None, **kwargs) -> List[Good.VkAccount]:
        """vk_country[] (array) - List of allowed countries

vk_city[] (array) - List of allowed cities

vk_friend_min (number) - Minimum number of friends

vk_friend_max (number) - Maximum number of friends

vk_follower_min (number) - Minimum number of followers

vk_follower_max (number) - Maximum number of followers

vk_vote_min (number) - Minimum number of votes

vk_vote_max (number) - Maximum number of votes

sex (string) - Sex of account

tel (boolean) - Has linked mobile

email (boolean) - Has linked email

tfa (boolean) - Has enabled 2FA

relation[] (boolean) - Has linked mobile

group_follower_min (number) - Minimum number of group followers

group_follower_max (number) - Maximum number of group followers

groups_min (number) - Minimum number of groups

groups_max (number) - Maximum number of groups

admin_level (string) - Admin level

min_age (number) - Minimum age

max_age (number) - Maximum age

dig_min (number) - Minimum number of digits in ID

dig_max (number) - Maximum number of digits in ID

conversations_min (number) - Minimum number of conversations

conversations_max (number) - Maximum number of conversations

reg (number) - How old is the account

reg_period (string) - In what notation is time measured

mcountry[] (array) - List of allowed countries of phone number

not_mcountry[] (array) - List of excluded countries of phone number

opened_profile (boolean) - Opened account profile"""
        return await super().search(page, pmin, pmax, title, parse_sticky_items, parse_same_items, game, **kwargs)


from typing import List

from lztmarket.Types import Good
from ....Types import Good, Category
from .BaseGame import BaseGame
from ....Types.AccountManage import AccountManager


class Discord(BaseGame):

    def __init__(self, wrapper) -> None:
        super().__init__(wrapper)
        self.categ_obj = Category.DISCORD
        self.name = self.categ_obj.name
        self.categ_id = self.categ_obj.id

    async def search(self, page: int = 1, pmin: int | None = None, pmax: int | None = None, title: str | None = None, parse_sticky_items: bool | None = None, parse_same_items: bool | None = None, game: list[int] | None = None, **kwargs) -> List[AccountManager]:
        """tel (boolean) - Has linked mobile

nitro (boolean) - Has Nitro

billing (boolean) - Has billing

gifts (boolean) - Has gifts

quarantined (boolean) - Кодер еблан, почему вообще заблокированные акки можно заливать?

condition[] (array) - List of account conditions

chat_min (number) - Minimum number of chats

chat_max (number) - Maximum number of chats

reg (number) - How old is the account

reg_period (string) - In what notation is time measured

locale[] (array) - List of regions

not_locale[] (array) - List of regions that won't be included

badge[] (array) - List of badges"""
        return await super().search(page, pmin, pmax, title, parse_sticky_items, parse_same_items, game, **kwargs)


import logging
import time
from .ApiExceptions import TimeLimitReached, ApiError

import httpx


logging.basicConfig(
    format="%(asctime)s %(levelname)s %(pathname)s:%(lineno)d %(message)s")


class Wrapper:
    """Class for sending requests to the server.
    """

    __if_created = False

    def __new__(cls, *args, **kwargs):
        """Creates a new instance of the class.

    Raises a warning if more than one instance of the class is created, as this can lead to IP blocking.

    Args:
    *args: positional arguments to be passed to the parent class constructor.
    **kwargs: keyword arguments to be passed to the parent class constructor.

    Returns:
    An instance of the class.
    """
        if cls.__if_created:
            logging.warning(
                "Creating more than one instance of a class can lead to IP blocking.")

        cls.__if_created = True
        return super().__new__(cls)

    def __init__(self, api_key: str) -> None:
        """
        Creates a new instance of the Wrapper class.

        Args:
        api_key (str): the API key for authentication on the server.
        """

        logging.debug("New instance of Wrapper created.")
        self._api_key = api_key
        self._last_request_timestamp = None
        self._end_point = "https://api.lzt.market"
        self.client = httpx.AsyncClient()

    def __ip_block_protect(func):
        async def wrapper(self, *args, **kwargs):
            if not self.can_send:
                raise TimeLimitReached(
                    "You cannot send a request at this time, as it will lead to a blocking of your ip address. "
                    "Please wait. Use the 'can_send' attribute to check if the request can be sent.")
            self._last_request_timestamp = int(time.time())
            return await func(self, *args, **kwargs)
        return wrapper

    @property
    def can_send(self) -> bool:
        return not (self._last_request_timestamp and int(time.time()) - self._last_request_timestamp < 4)

    @__ip_block_protect
    async def _execute(self, path: str, method: str, params: dict = None, data: str = None):
        """Executes an HTTP request to the specified endpoint and returns the response as a JSON object.

        Args:
            path (str): The path component of the URL.
            method (str): The HTTP method to use for the request (e.g., GET, POST, PUT, DELETE).
            params (dict, optional): A dictionary of query parameters to include in the request URL.
            data (str, optional): The request body as a string.

        Returns:
            The response from the HTTP request as a JSON object.
        """
        HEADERS = {
            'Authorization': f'Bearer {self._api_key}',
            'accept': 'application/json'
        }
        response = await self.client.request(
            url=f"{self._end_point}{path}",
            method=method,
            params=params,
            data=data,
            headers=HEADERS,
            timeout=100000)
        json_response = response.json()
        if 'errors' in json_response:
            if isinstance(json_response['errors'], list):
                raise ApiError(f"Got err from host: {json_response['errors'][0]}")
            elif isinstance(json_response['errors'], dict):
                raise ApiError(f"Got err from host: {json_response['errors'].values()[0]}")
        return json_response

# 君の中にある　赤と青き線
# それらが結ばれるのは　心の臓
# 風の中でも負けないような声で
# 届ける言葉を今は育ててる



from typing import List

from lztmarket.Types import Good
from ....Types import Good, Category
from .BaseGame import BaseGame
from ....Types.AccountManage import AccountManager


class Origin(BaseGame):

    def __init__(self, wrapper) -> None:
        super().__init__(wrapper)
        self.categ_obj = Category.ORIGIN
        self.name = self.categ_obj.name
        self.categ_id = self.categ_obj.id

    async def search(self, page: int = 1, pmin: int | None = None, pmax: int | None = None, title: str | None = None, parse_sticky_items: bool | None = None, parse_same_items: bool | None = None, game: list[int] | None = None, **kwargs) -> List[AccountManager]:
        """game (array) - List of games

country[] (array) - List of allowed countries

not_country[] (array) - List of disallowed countries

al_rank_group[] (array) - List of Apex Legends rank groups

al_level_min (number) - Minimum level in Apex Legends

al_level_max (number) - Maximum level in Apex Legends

xbox_connected (boolean) - Xbox connected to account

subscription (string) - Name of subscription

subscription_length (number) - Length of subscription

subscription_period (string) - In what notation is time measured"""
        return await super().search(page, pmin, pmax, title, parse_sticky_items, parse_same_items, game, **kwargs)


from typing import List
from ....Types import Good, Category
from .BaseGame import BaseGame
from ....Types.AccountManage import AccountManager


class Steam(BaseGame):

    def __init__(self, wrapper) -> None:
        super().__init__(wrapper)
        self.categ_obj = Category.STEAM
        self.name = self.categ_obj.name
        self.categ_id = self.categ_obj.id

    async def search(self, page: int = 1, pmin: int | None = None, pmax: int | None = None, title: str | None = None, parse_sticky_items: bool | None = None, parse_same_items: bool | None = None, game: list[int] | None = None, **kwargs) -> List[AccountManager]:
            """game[] (array) - List of games

            hours_played (array) - List of minimum hours played by game

            hours_played_max (array) - List of maximum hours played by game

            vac (number) - List of VAC bans by game

            rt (boolean) - Has red sign

            prime (boolean) - Has Prime in CS:GO

            daybreak (number) - Number of days the account has been offline

            limit (boolean) - Has 5$ limit

            mafile (boolean) - Has .mafile

            reg (number) - How old is the account

            reg_period (string) - In what notation is time measured

            lmin (number) - Minimum level

            lmax (number) - Maximum level

            rmin (number) - Minimum rank in CS:GO Matchmaking

            rmax (number) - Maximum rank in CS:GO Matchmaking

            wingman_rmin (number) - Minimum rank in CS:GO Wingman

            wingman_rmax (number) - Maximum rank in CS:GO Wingman

            no_vac (boolean) - Has no VAC ban

            mm_ban (boolean) - Has CS:GO Matchmaking ban

            balance_min (number) - Minimum balance

            balance_max (number) - Maximum balance

            inv_game (number) - Game ID to check inventory price

            inv_min (number) - Minimum inventory price for game

            inv_max (number) - Maximum inventory price for game

            friend_min (number) - Minimum number of friends

            friend_max (number) - Maximum number of friends

            gmin (number) - Minimum number of games

            gmax (number) - Maximum number of games

            win_count_min (number) - Minimum number of wins

            win_count_max (number) - Maximum number of wins

            medal[] (array) - List of medal names

            medal_id[] (array) - List of medal IDs

            medal_min (number) - Minimum number of medals

            medal_max (number) - Maximum number of medals

            gift[] (array) - List of gifts

            gift_min (number) - Minimum number of gifts

            gift_max (number) - Maximum number of gifts

            recently_hours_min (number) - Minimum number of recently played hours

            recently_hours_max (number) - Maximum number of recently played hours

            country[] (array) - List of allowed countries

            not_country[] (array) - List of disallowed countries

            csgo_profile_rank (string) - CS:GO rank (>=)

            csgo_profile_rank_min (number) - Minimum CS:GO rank

            csgo_profile_rank_max (number) - Maximum CS:GO rank

            solommr_min (number) - Minimum number of Dota 2 MMR

            solommr_max (number) - Maximum number of Dota 2 MMR

            d2_game_count_min (number) - Minimum number of Dota 2 games

            d2_game_count_max (number) - Maximum number of Dota 2 games

            d2_win_count_min (number) - Minimum number of Dota 2 wins

            d2_win_count_max (number) - Maximum number of Dota 2 wins

            d2_behavior_min (number) - Minimum number of Dota 2 behavior

            d2_behavior_max (number) - Maximum number of Dota 2 behavior

            faceit_lvl_min (number) - Minimum FACEIT level

            faceit_lvl_max (number) - Maximum FACEIT level

            points_min (number) - Minimum number of Steam points

            points_max (number) - Maximum number of Steam points

            relevant_gmin (number) - Minimum number of relevant games

            relevant_gmax (number) - Maximum number of relevant games

            last_trans_date (number) - How old is last transaction

            last_trans_date_period (string) - In what notation is time measured

            last_trans_date_later (number) - How new is last transaction

            last_trans_date_period_later (string) - In what notation is time measured

            no_trans (boolean) - Has no transactions

            trans (boolean) - Has transactions"""
            return await super().search(page, pmin, pmax, title, parse_sticky_items, parse_same_items, game, **kwargs)



from typing import List

from lztmarket.Types import Good
from ....Types import Good, Category
from .BaseGame import BaseGame
from ....Types.AccountManage import AccountManager


class VPN(BaseGame):

    def __init__(self, wrapper) -> None:
        super().__init__(wrapper)
        self.categ_obj = Category.VPN
        self.name = self.categ_obj.name
        self.categ_id = self.categ_obj.id

    async def search(self, page: int = 1, pmin: int | None = None, pmax: int | None = None, title: str | None = None, parse_sticky_items: bool | None = None, parse_same_items: bool | None = None, game: list[int] | None = None, **kwargs) -> List[AccountManager]:
        """game (array) - List of games

daybreak (number) - Number of days the account has been offline

country[] (array) - List of allowed countries

not_country[] (array) - List of disallowed countries

edit_btag (boolean) - Can edit BattleTag

changeable_fn (boolean) - Can edit full name

real_id (boolean) - Read name

tel (boolean) - Has linked mobile

parent_control (boolean) - Has enabled parent control

cookies (boolean) - Login by cookies

lmin (number) - Minimum level in Overwatch

lmax (number) - Maximum level in Overwatch

balance_min (number) - Minimum balance

balance_max (number) - Maximum balance"""
        return await super().search(page, pmin, pmax, title, parse_sticky_items, parse_same_items, game, **kwargs)


from ...Types.AccountManage import AccountManager
from ...ApiWrapper import Wrapper

class Good:

    def __init__(self, wrapper: Wrapper) -> None:
        self.__wrapper = wrapper

    async def get(self, id: int, force: bool=False) -> AccountManager:
        """
        Получает аккаунт по id.

        :param id: идентификатор аккаунта.
        :force: информация об аккаунте не будет получена.
        Полезно, если требуется совершить многжество действий.
        К примеру, поднять несколько аккаунтов.
        :type id: int
        :return: экземпляр класса AccountManager.
        :rtype: AccountManager
        """
        am = AccountManager(self.__wrapper, id)
        if not force:
            await am.get_info()
        return am

    async def add(
            self,
            title: str,
            price: int,
            category_id: int,
            currency: str,
            item_origin: str,
            extended_guarantee: int,
            email_login_data: str=None,
            email_type: str=None,
            allow_ask_discount: bool=None,
            proxy_id: int=None,
            random_proxy: bool=None,
            description: str=None,
            information: str=None,
            has_email_login_data: bool=False,
            title_en: str=None,
            ) -> AccountManager:
        params = dict(
            title=title, 
            price=price, 
            category_id=category_id, 
            currency=currency,
            item_origin=item_origin, 
            extended_guarantee=extended_guarantee)
        
        if email_login_data is not None: params['email_login_data']=email_login_data
        if email_type is not None: params['email_type']=email_type
        if allow_ask_discount is not None: params['allow_ask_discount']=allow_ask_discount
        if proxy_id is not None: params['proxy_id']=proxy_id
        if random_proxy is not None: params['random_proxy']=random_proxy
        if description is not None: params['description']=description
        if information is not None: params['information']=information
        if has_email_login_data is not None: params['has_email_login_data']=has_email_login_data
        if title_en is not None: params['title_en']=title_en

        reponse = await self.__wrapper._execute(
            "/item/add",
            "post",
            params=params
        )

        return AccountManager(self.__wrapper, reponse['item']['item_id'])

    



from ...ApiWrapper import Wrapper
from ...Types import TimeValues, Currency, PaymentModel, PaymentType
from datetime import datetime


class Payment:

    def __init__(self, wrapper: Wrapper) -> None:
        self.__wrapper = wrapper

    async def generate_link(
            self,
            my_username: str,
            amount: int,
            comment: str="",
            redirect: str=""
    ):
        """Generate payment link"""
        return f"https://lzt.market/balance/transfer?username={my_username}&amount={amount}&comment={comment}&redirect={redirect}"

    async def make(
            self,
            amount: int,
            secret: str,
            currency: str = "rub",
            user_id: int = None,
            username: str = None,
            comment: str = None,
            hold_length_value: int = None,
            hold_length_option: str = None) -> None:
        """
    Создает перевод денежных средств на кошелек пользователя.

    - amount: Сумма перевода в копейках.
    - secret: Ответ на секретный вопрос пользователя.
    - currency: Валюта перевода. Допустимые значения: "cny", "usd", "rub", "eur", "uah", "kzt", "byn", "gbp".
    - user_id: Идентификатор пользователя.
    - username: Имя пользователя.
    - comment: Комментарий к переводу.
    - hold_length_value: Время удержания перевода.
    - hold_length_option: Единица измерения времени удержания перевода. Допустимые значения: "day", "hour", "month", "week", "year".
    """
        params = {}

        if user_id is None and username is None:
            raise ValueError("username or user_id must be specified !")

        if user_id:
            params['user_id'] = user_id
        elif username:
            params['username'] = username

        if secret is None:
            raise ValueError("secret must be specified !")
        params['secret_answer'] = secret

        if comment is not None:
            params['comment'] = comment

        if hold_length_value:
            if not hold_length_option in TimeValues.__dict__.values():
                raise ValueError(
                    f"Invalid hold_length_option: {hold_length_option}. Use 'from lztmarket.Types import TimeValues'")

            params['transfer_hold'] = True
            params['hold_length_value'] = hold_length_value
            params['hold_length_option'] = hold_length_option

        if not currency in Currency.__dict__.values():
            raise ValueError(
                f"Invalid currency: {currency}. Use 'from lztmarket.Types import Currency'")
        params['currency'] = currency

        params['amount'] = amount

        await self.__wrapper._execute(
            '/balance/transfer',
            'post',
            params=params
        )

    async def history(
            self,
            my_id: int,
            payment_type: str=None,
            pmin: int=None,
            pmax: int=None,
            receiver: int=None,
            sender: int=None,
            startDate: datetime.isoformat=None,
            endDate: datetime.isoformat=None,
            wallet: str=None,
            comment: str=None,
            is_hold: bool=None,
            start_by_operation_id: int=None
            ) -> list[PaymentModel.Payment]:
        
        params = {}
        """Получает список платежей для определенного пользователя.

        :param my_id: идентификатор пользователя.
        :type my_id: int
        :param payment_type: тип платежа, один из вариантов PaymentType.
        :type payment_type: str, optional
        :param pmin: минимальная сумма платежа.
        :type pmin: int, optional
        :param pmax: максимальная сумма платежа.
        :type pmax: int, optional
        :param receiver: идентификатор пользователя-получателя платежа.
        :type receiver: int, optional
        :param sender: идентификатор пользователя-отправителя платежа.
        :type sender: int, optional
        :param startDate: дата начала периода, за который запрашиваются платежи.
        :type startDate: datetime.isoformat, optional
        :param endDate: дата окончания периода, за который запрашиваются платежи.
        :type endDate: datetime.isoformat, optional
        :param wallet: кошелек, с которого был произведен платеж.
        :type wallet: str, optional
        :param comment: комментарий к платежу.
        :type comment: str, optional
        :param is_hold: флаг, указывающий является ли платеж замороженным.
        :type is_hold: bool, optional
        :param start_by_operation_id: идентификатор платежа, с которого начинать выборку.
        :type start_by_operation_id: int, optional
        :return: список платежей.
        :rtype: list[PaymentModel.Payment]
        :raises ValueError: если передан неверный тип платежа."""
        if not payment_type in PaymentType.__dict__.values():
            raise ValueError(f"Invalid value payment_type. Use 'from lztmarket.Types import PaymentType'")
        
        params['type'] = payment_type
        
        if pmin:
            params['pmin'] = pmin
        
        if pmax:
            params['pmax'] = pmax

        if receiver:
            params['receiver'] = receiver

        if sender:
            params['sender'] = sender

        if startDate:
            params['startDate'] = startDate
        
        if endDate:
            params['endDate'] = endDate

        if wallet:
            params['wallet'] = wallet

        if comment:
            comment['comment'] = comment

        if is_hold is not None:
            params['is_hold'] = int(is_hold)

        if start_by_operation_id:
            params['operation_id_lt'] = start_by_operation_id

        un_sorted_data = await self.__wrapper._execute(
            f"/user/{my_id}/payments",
            "get",
            params=params
        )

        result = []

        for payment in un_sorted_data['payments'].keys():
            print(payment)
            result.append(PaymentModel.Payment.parse_obj(un_sorted_data['payments'][payment]))
        
        return result


from ...ApiWrapper import Wrapper
from typing import List
from ...Types import Good, Category
from ...Utils import Response
from . import GamesModels



class Games():
    def __init__(self, wrapper: Wrapper):
        self.__wrapper = wrapper
        self.Steam = GamesModels.Steam(wrapper)
        self.Vk = GamesModels.VK(wrapper)
        self.Origin = GamesModels.Origin(wrapper)
        self.Warface = GamesModels.Warface(wrapper)
        self.Uplay = GamesModels.Uplay(wrapper)
        self.SocialClub = GamesModels.SocialClub(wrapper)
        self.Fortnite = GamesModels.Fortnite(wrapper)
        self.Instagram = GamesModels.Instagram(wrapper)
        self.Battlenet = GamesModels.Battlenet(wrapper)
        self.EpicGames = GamesModels.EpicGames(wrapper)
        self.Valorant = GamesModels.Valorant(wrapper)
        self.WorldOfTanks = GamesModels.WorldOfTanks(wrapper)
        self.Blitz = GamesModels.Blitz(wrapper)
        self.Supercell = GamesModels.Supercell(wrapper)
        self.GenshinImpact = GamesModels.GenshinImpact(wrapper)
        self.EscapeFromTarkov = GamesModels.EscapeFromTarkov(wrapper)
        self.Vpn = GamesModels.VPN(wrapper)
        self.TikTok = GamesModels.TikTok(wrapper)
        self.Discord = GamesModels.Discord(wrapper)
        self.Cinema = GamesModels.Cinema(wrapper)
        self.Telegram = GamesModels.Telegram(wrapper)
        self.YouTube = GamesModels.YouTube(wrapper)
        self.Spotify = GamesModels.Spotify(wrapper)
        self.WarThunder = GamesModels.WarThunder(wrapper)



    async def last(self, page: int = 1) -> List[Good.Account]:
        """Displays a list of latest accounts."""
        response = await self.__wrapper._execute(
            "/",
            "get",
            params={"page": page}
        )
        return Response.response_to_accounts(self.__wrapper, response['items'])



# from distutils.core import setup
from setuptools import setup, find_packages
setup(
  name = 'lztmarketapi',        
  packages = find_packages(),
  include_package_data=True,
  version = '0.2.0',    
  license='apache-2.0',      
  description = 'Данная библиотека создана для взаимодействия с api lzt.market.',   
  author = 'KazariFox',                  
  author_email = '',     
  url = 'https://github.com/KazariFox/AsyncMarketLztApi',   
  keywords = ['lzt', 'lolzteam', 'lolzteam market', 'api'],  
  install_requires=[           
          'pydantic',
          'httpx',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      
    'Intended Audience :: Developers',      
    'Topic :: Software Development :: Build Tools',
    'Programming Language :: Python :: 3.10',
    'Programming Language :: Python :: 3.11',
  ],
)


from ..ApiWrapper import Wrapper
from .Games import Games
from .Good import Good
from .Payment import Payment
from .Me import Me


class MarketClient(Wrapper):

    def __init__(self, api_key: str) -> None:
        """Args:
        api_key (str): the API key for authentication on the server.
        """

        super().__init__(api_key=api_key)
        self.Goods = Games(self)
        self.Good = Good(self)
        self.Payment = Payment(self)
        self.Me = Me(self)



from typing import List

from lztmarket.Types import Good
from ....Types import Good, Category
from .BaseGame import BaseGame
from ....Types.AccountManage import AccountManager


class GenshinImpact(BaseGame):

    def __init__(self, wrapper) -> None:
        super().__init__(wrapper)
        self.categ_obj = Category.GENSHIN_IMPACT
        self.name = self.categ_obj.name
        self.categ_id = self.categ_obj.id

    async def search(self, page: int = 1, pmin: int | None = None, pmax: int | None = None, title: str | None = None, parse_sticky_items: bool | None = None, parse_same_items: bool | None = None, game: list[int] | None = None, **kwargs) -> List[AccountManager]:
        """email (boolean) - Has linked email

tel (boolean) - Has linked mobile

character[] (string) - List of characters

weapon[] (string) - List of characters

region (string) - Region

ea (boolean) - Has linked external accounts

legendary_min (number) - Minimum number of legendary characters

legendary_max (number) - Maximum number of legendary characters

constellation_min (number) - Minimum number of constellations on legendary characters

constellation_max (number) - Maximum number of constellations on legendary characters

legendary_weapon_min (number) - Minimum number of legendary weapon characters

legendary_weapon_max (number) - Maximum number of legendary weapon characters

char_min (number) - Minimum number of characters

char_max (number) - Maximum number of characters

level_min (number) - Minimum level

level_max (number) - Maximum level"""
        return await super().search(page, pmin, pmax, title, parse_sticky_items, parse_same_items, game, **kwargs)


INCOME = 'income'
COST = 'cost'
REFILLED_BALANCE = 'refilled_balance'
WITHDRAWAL_BALANCE = 'withdrawal_balance'
PAID_ITEM = 'paid_item'
SOLD_ITEM = 'sold_item'
MONEY_TRANSFER = 'money_transfer'
RECEIVING_MONEY = 'receiving_money'
INTERNAL_PURCHASE = 'internal_purchase'
